@@ -61,6 +61,7 @@
 #include "registry.h"
 #include "ringbuffer.h"
 #include "segment.h"
+#include "streamvolume.h"
 #include "structure.h"
 #include "systemclock.h"
 #include "taglist.h"
@@ -83,6 +84,7 @@
 #include "alsasink.h"
 #include "alsasrc.h"
 #include "audioconvert.h"
+#include "audiorate.h"
 #include "audioresample.h"
 #include "audiotestsrc.h"
 #include "capsfilter.h"
@@ -111,6 +113,8 @@
 #include "playbin2.h"
 #include "playbin.h"
 #include "queue.h"
+#include "queue2.h"
+#include "subtitleoverlay.h"
 #include "tcpclientsink.h"
 #include "tcpclientsrc.h"
 #include "tcpserversink.h"
@@ -147,6 +151,7 @@ GType gst_alsa_src_get_type(void);
 GType gst_audio_clock_get_type(void);
 GType gst_audio_convert_get_type(void);
 GType gst_audio_filter_get_type(void);
+GType gst_audio_rate_get_type(void);
 GType gst_audio_resample_get_type(void);
 GType gst_audio_sink_get_type(void);
 GType gst_audio_src_get_type(void);
@@ -201,8 +206,10 @@ GType gst_plugin_get_type(void);
 GType gst_plugin_feature_get_type(void);
 GType gst_push_src_get_type(void);
 GType gst_queue_get_type(void);
+GType gst_queue2_get_type(void);
 GType gst_registry_get_type(void);
 GType gst_ring_buffer_get_type(void);
+GType gst_subtitle_overlay_get_type(void);
 GType gst_system_clock_get_type(void);
 GType gst_tcp_client_sink_get_type(void);
 GType gst_tcp_client_src_get_type(void);
@@ -255,6 +262,7 @@ namespace Gst {  class AlsaSrc_Class { public: static Glib::ObjectBase* wrap_new
 namespace Gst {  class AudioClock_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class AudioConvert_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class AudioFilter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class AudioRate_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class AudioResample_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class AudioSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class AudioSrc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -309,8 +317,10 @@ namespace Gst {  class Plugin_Class { public: static Glib::ObjectBase* wrap_new(
 namespace Gst {  class PluginFeature_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class PushSrc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Queue_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class Queue2_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Registry_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class RingBuffer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class SubtitleOverlay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class SystemClock_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TCPClientSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TCPClientSrc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -363,6 +373,7 @@ void wrap_init()
   Glib::wrap_register(gst_audio_clock_get_type(), &Gst::AudioClock_Class::wrap_new);
   Glib::wrap_register(gst_audio_convert_get_type(), &Gst::AudioConvert_Class::wrap_new);
   Glib::wrap_register(gst_audio_filter_get_type(), &Gst::AudioFilter_Class::wrap_new);
+  Glib::wrap_register(gst_audio_rate_get_type(), &Gst::AudioRate_Class::wrap_new);
   Glib::wrap_register(gst_audio_resample_get_type(), &Gst::AudioResample_Class::wrap_new);
   Glib::wrap_register(gst_audio_sink_get_type(), &Gst::AudioSink_Class::wrap_new);
   Glib::wrap_register(gst_audio_src_get_type(), &Gst::AudioSrc_Class::wrap_new);
@@ -417,8 +428,10 @@ void wrap_init()
   Glib::wrap_register(gst_plugin_feature_get_type(), &Gst::PluginFeature_Class::wrap_new);
   Glib::wrap_register(gst_push_src_get_type(), &Gst::PushSrc_Class::wrap_new);
   Glib::wrap_register(gst_queue_get_type(), &Gst::Queue_Class::wrap_new);
+  Glib::wrap_register(gst_queue2_get_type(), &Gst::Queue2_Class::wrap_new);
   Glib::wrap_register(gst_registry_get_type(), &Gst::Registry_Class::wrap_new);
   Glib::wrap_register(gst_ring_buffer_get_type(), &Gst::RingBuffer_Class::wrap_new);
+  Glib::wrap_register(gst_subtitle_overlay_get_type(), &Gst::SubtitleOverlay_Class::wrap_new);
   Glib::wrap_register(gst_system_clock_get_type(), &Gst::SystemClock_Class::wrap_new);
   Glib::wrap_register(gst_tcp_client_sink_get_type(), &Gst::TCPClientSink_Class::wrap_new);
   Glib::wrap_register(gst_tcp_client_src_get_type(), &Gst::TCPClientSrc_Class::wrap_new);
@@ -459,6 +472,7 @@ void wrap_init()
   Gst::AudioClock::get_type();
   Gst::AudioConvert::get_type();
   Gst::AudioFilter::get_type();
+  Gst::AudioRate::get_type();
   Gst::AudioResample::get_type();
   Gst::AudioSink::get_type();
   Gst::AudioSrc::get_type();
@@ -513,8 +527,10 @@ void wrap_init()
   Gst::PluginFeature::get_type();
   Gst::PushSrc::get_type();
   Gst::Queue::get_type();
+  Gst::Queue2::get_type();
   Gst::Registry::get_type();
   Gst::RingBuffer::get_type();
+  Gst::SubtitleOverlay::get_type();
   Gst::SystemClock::get_type();
   Gst::TCPClientSink::get_type();
   Gst::TCPClientSrc::get_type();
